import React, { useEffect, useState, useMemo } from "react";
import { RouterContext } from "./RouterContext";
import { createHistory, getHashPath } from "./history";
import { createRouteMatcher } from "./routeMatcher";
import { getPathWithoutBasename } from "./basename";
import { simpleRouteMatcherFactory } from "./simpleRouteMatcherFactory";
export const Router = ({ basename = "", mode, routeMatcherFactory = simpleRouteMatcherFactory, children, }) => {
    const hashMode = mode === "hash";
    const [path, setPath] = useState(() => (hashMode ? getHashPath() : getPathWithoutBasename(basename)));
    const history = useMemo(() => createHistory(hashMode, basename, setPath), [setPath, basename, hashMode]);
    const matchRoute = useMemo(() => createRouteMatcher(routeMatcherFactory), [routeMatcherFactory]);
    const router = useMemo(() => ({
        basename,
        path,
        history,
        matchRoute,
        urlTo: history.urlTo,
    }), [basename, path, history, matchRoute]);
    useEffect(() => history.stop, [history]);
    return React.createElement(RouterContext.Provider, { value: router }, children);
};
